pub struct SequenceCollection {
pub metadata: SequenceCollectionMetadata,
pub sequences: Vec<SequenceRecord>,
}Expand description
A single Sequence Collection, which may or may not hold data.
Fields
metadata: SequenceCollectionMetadataCollection metadata (digest, level 1 digests, n_sequences, file_path)
sequences: Vec<SequenceRecord>Vector of SequenceRecords, which contain metadata (name, length, digests, alphabet) and optionally the actual sequence data.
Implementations
Sourceimpl SequenceCollection
impl SequenceCollection
Sourcepub fn from_records(records: Vec<SequenceRecord>) -> Self
pub fn from_records(records: Vec<SequenceRecord>) -> Self
Create a SequenceCollection from a vector of SequenceRecords.
Sourcepub fn to_level2(&self) -> CollectionLevel2
pub fn to_level2(&self) -> CollectionLevel2
Return level 2 representation (full arrays, spec format).
Transposes Vec
Sourcepub fn build_sorted_sequences(&self) -> Vec<String>
pub fn build_sorted_sequences(&self) -> Vec<String>
Build the sorted_sequences array as SQ.-prefixed digest strings, sorted lexicographically.
Sourcepub fn build_name_length_pairs(&self) -> Vec<Value>
pub fn build_name_length_pairs(&self) -> Vec<Value>
Build the name_length_pairs array as JSON value objects {“length”: N, “name”: “X”}. Keys are in alphabetical order per canonical JSON.
Sourcepub fn build_sorted_name_length_pairs(&self) -> Vec<Value>
pub fn build_sorted_name_length_pairs(&self) -> Vec<Value>
Build the sorted_name_length_pairs array as JSON value objects, sorted by their canonical JSON digest.
Sourcepub fn compare(&self, other: &SequenceCollection) -> SeqColComparison
pub fn compare(&self, other: &SequenceCollection) -> SeqColComparison
Compare this collection with another, following the seqcol spec comparison algorithm.
Dynamically includes ancillary attributes (name_length_pairs, sorted_name_length_pairs, sorted_sequences) when present in each collection’s metadata.